==> dif-database-repository-2.1.7-24-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ErrorLog.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;
import pt.digitalis.utils.common.DateUtils;

/**
 * ErrorLog
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class ErrorLog extends AbstractBeanAttributes implements java.io.Serializable {

    /** ErrorLog attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** processName column */
        public static final String PROCESSNAME = "processName";
        /** errorDescription column */
        public static final String ERRORDESCRIPTION = "errorDescription";
        /** erroDate column */
        public static final String ERRODATE = "erroDate";
        /** appName column */
        public static final String APPNAME = "appName";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("processName");
            list.add("errorDescription");
            list.add("erroDate");
            list.add("appName");

            return list;
        }
    }

    /** ErrorLog FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("processName".equalsIgnoreCase(attributeName))
            return processName;
        if ("errorDescription".equalsIgnoreCase(attributeName))
            return errorDescription;
        if ("erroDate".equalsIgnoreCase(attributeName))
            return erroDate;
        if ("appName".equalsIgnoreCase(attributeName))
            return appName;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("processName".equalsIgnoreCase(attributeName))
            processName = (String)attributeValue;
        if ("errorDescription".equalsIgnoreCase(attributeName))
            errorDescription = (String)attributeValue;
        if ("erroDate".equalsIgnoreCase(attributeName))
            erroDate = (Date)attributeValue;
        if ("appName".equalsIgnoreCase(attributeName))
            appName = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** processName private attribute */
    private String processName;

    /** errorDescription private attribute */
    private String errorDescription;

    /** erroDate private attribute */
    private Date erroDate;

    /** appName private attribute */
    private String appName;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            if ("erroDate".equalsIgnoreCase(attributeName))
        	    return DateUtils.simpleDateToString((Date)value);
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ErrorLog() {
    }

	/** 
	 * minimal constructor
	 *
     * @param erroDate
     * @param appName
    }
	 */
    public ErrorLog(Date erroDate, String appName) {
        this.erroDate = erroDate;
        this.appName = appName;
    }

    /**
     * full constructor
	 *
     * @param processName
     * @param errorDescription
     * @param erroDate
     * @param appName
     */
    public ErrorLog(String processName, String errorDescription, Date erroDate, String appName) {
        this.processName = processName;
        this.errorDescription = errorDescription;
        this.erroDate = erroDate;
        this.appName = appName;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return ErrorLog modified instance
     */
    public ErrorLog setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * processName getter method
     *
     * @return processName method
     */
    public String getProcessName() {
        return this.processName;
    }
    
    /**       
     * processName setter method
     *
     * @param processName
     *
     * @return ErrorLog modified instance
     */
    public ErrorLog setProcessName(String processName) {
        this.processName = processName;
        
        return this;
    }
    /**       
     * errorDescription getter method
     *
     * @return errorDescription method
     */
    public String getErrorDescription() {
        return this.errorDescription;
    }
    
    /**       
     * errorDescription setter method
     *
     * @param errorDescription
     *
     * @return ErrorLog modified instance
     */
    public ErrorLog setErrorDescription(String errorDescription) {
        this.errorDescription = errorDescription;
        
        return this;
    }
    /**       
     * erroDate getter method
     *
     * @return erroDate method
     */
    public Date getErroDate() {
        return this.erroDate;
    }
    
    /**       
     * erroDate setter method
     *
     * @param erroDate
     *
     * @return ErrorLog modified instance
     */
    public ErrorLog setErroDate(Date erroDate) {
        this.erroDate = erroDate;
        
        return this;
    }
    /**       
     * appName getter method
     *
     * @return appName method
     */
    public String getAppName() {
        return this.appName;
    }
    
    /**       
     * appName setter method
     *
     * @param appName
     *
     * @return ErrorLog modified instance
     */
    public ErrorLog setAppName(String appName) {
        this.appName = appName;
        
        return this;
    }

    /**
     * Creates a String representation of the ErrorLog object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("processName").append("='").append(getProcessName()).append("' ");			
        buffer.append("errorDescription").append("='").append(getErrorDescription()).append("' ");			
        buffer.append("erroDate").append("='").append(getErroDate()).append("' ");			
        buffer.append("appName").append("='").append(getAppName()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ErrorLog object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ErrorLog other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("processName".equalsIgnoreCase(attributeName))
        	this.processName = attributeValue;

        if ("errorDescription".equalsIgnoreCase(attributeName))
        	this.errorDescription = attributeValue;

        if ("erroDate".equalsIgnoreCase(attributeName))
	        try {
        	    this.erroDate = DateUtils.stringToSimpleDate(attributeValue);
	        } catch (ParseException e) {
	            // Do nothing. The value will not be set!
	        }

        if ("appName".equalsIgnoreCase(attributeName))
        	this.appName = attributeValue;

    }


}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ErrorLog.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;
import pt.digitalis.utils.common.DateUtils;

/**
 * ErrorLog Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class ErrorLog extends AbstractBeanAttributes implements java.io.Serializable {

    /** ErrorLog attributes enumeration */
    public static class Fields {

        /** id column */
        public static final String ID = "id";
        /** processName column */
        public static final String PROCESSNAME = "processName";
        /** errorDescription column */
        public static final String ERRORDESCRIPTION = "errorDescription";
        /** erroDate column */
        public static final String ERRODATE = "erroDate";
        /** appName column */
        public static final String APPNAME = "appName";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("processName");
            list.add("errorDescription");
            list.add("erroDate");
            list.add("appName");

            return list;
        }
    }

    /** ErrorLog FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("processName".equalsIgnoreCase(attributeName))
            return processName;
        if ("errorDescription".equalsIgnoreCase(attributeName))
            return errorDescription;
        if ("erroDate".equalsIgnoreCase(attributeName))
            return erroDate;
        if ("appName".equalsIgnoreCase(attributeName))
            return appName;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("processName".equalsIgnoreCase(attributeName))
            processName = (String) attributeValue;
        if ("errorDescription".equalsIgnoreCase(attributeName))
            errorDescription = (String) attributeValue;
        if ("erroDate".equalsIgnoreCase(attributeName))
            erroDate = (Date) attributeValue;
        if ("appName".equalsIgnoreCase(attributeName))
            appName = (String) attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** processName private attribute */
    private String processName;

    /** errorDescription private attribute */
    private String errorDescription;

    /** erroDate private attribute */
    private Date erroDate;

    /** appName private attribute */
    private String appName;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            if ("erroDate".equalsIgnoreCase(attributeName))
                return DateUtils.simpleDateToString((Date) value);
            return value.toString().trim();
        }
    }

    // Constructors

    /**
     * default constructor
     */
    public ErrorLog()
    {}

    /**
     * minimal constructor
     *
     * @param erroDate
     * @param appName
     *            }
     */
    public ErrorLog(Date erroDate, String appName)
    {
        this.erroDate = erroDate;
        this.appName = appName;
    }

    /**
     * full constructor
     *
     * @param processName
     * @param errorDescription
     * @param erroDate
     * @param appName
     */
    public ErrorLog(String processName, String errorDescription, Date erroDate, String appName)
    {
        this.processName = processName;
        this.errorDescription = errorDescription;
        this.erroDate = erroDate;
        this.appName = appName;
    }

    // Property accessors

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * id setter method
     *
     * @param id
     * @return ErrorLog modified instance
     */
    public ErrorLog setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * processName getter method
     *
     * @return processName method
     */
    public String getProcessName()
    {
        return this.processName;
    }

    /**
     * processName setter method
     *
     * @param processName
     * @return ErrorLog modified instance
     */
    public ErrorLog setProcessName(String processName)
    {
        this.processName = processName;

        return this;
    }

    /**
     * errorDescription getter method
     *
     * @return errorDescription method
     */
    public String getErrorDescription()
    {
        return this.errorDescription;
    }

    /**
     * errorDescription setter method
     *
     * @param errorDescription
     * @return ErrorLog modified instance
     */
    public ErrorLog setErrorDescription(String errorDescription)
    {
        this.errorDescription = errorDescription;

        return this;
    }

    /**
     * erroDate getter method
     *
     * @return erroDate method
     */
    public Date getErroDate()
    {
        return this.erroDate;
    }

    /**
     * erroDate setter method
     *
     * @param erroDate
     * @return ErrorLog modified instance
     */
    public ErrorLog setErroDate(Date erroDate)
    {
        this.erroDate = erroDate;

        return this;
    }

    /**
     * appName getter method
     *
     * @return appName method
     */
    public String getAppName()
    {
        return this.appName;
    }

    /**
     * appName setter method
     *
     * @param appName
     * @return ErrorLog modified instance
     */
    public ErrorLog setAppName(String appName)
    {
        this.appName = appName;

        return this;
    }

    /**
     * Creates a String representation of the ErrorLog object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("processName").append("='").append(getProcessName()).append("' ");
        buffer.append("errorDescription").append("='").append(getErrorDescription()).append("' ");
        buffer.append("erroDate").append("='").append(getErroDate()).append("' ");
        buffer.append("appName").append("='").append(getAppName()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

    /**
     * Compares the String representation of the ErrorLog object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(ErrorLog other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("processName".equalsIgnoreCase(attributeName))
            this.processName = attributeValue;

        if ("errorDescription".equalsIgnoreCase(attributeName))
            this.errorDescription = attributeValue;

        if ("erroDate".equalsIgnoreCase(attributeName))
            try
            {
                this.erroDate = DateUtils.stringToSimpleDate(attributeValue);
            }
            catch (ParseException e)
            {
                // Do nothing. The value will not be set!
            }

        if ("appName".equalsIgnoreCase(attributeName))
            this.appName = attributeValue;

    }

}
